Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1004)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java

Issue 2542203002: [Android History] Add Android history manager UI and bridge (Closed)
Patch Set: Rebase, drop changes to time.* Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java b/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
index 6e124262cc7c7d493e24a4f377d35d721b8b1448..7783b73627bdc350e86d3d12ea6726acf17924f2 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
@@ -5,7 +5,7 @@
package org.chromium.chrome.browser.widget.selection;
import android.content.Context;
-import android.support.graphics.drawable.VectorDrawableCompat;
+import android.graphics.drawable.Drawable;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
@@ -131,14 +131,11 @@ public class SelectableListLayout extends RelativeLayout {
/**
* Initializes the view shown when the selectable list is empty.
*
* @param emptyIconResId The icon to show when the selectable list is empty.
* @param emptyStringResId The string to show when the selectable list is empty.
*/
- public void initializeEmptyView(int emptyIconResId, int emptyStringResId) {
- mEmptyView.setCompoundDrawablesWithIntrinsicBounds(null,
- VectorDrawableCompat.create(getResources(), emptyIconResId,
- getContext().getTheme()),
- null, null);
+ public void initializeEmptyView(Drawable emptyDrawable, int emptyStringResId) {
+ mEmptyView.setCompoundDrawablesWithIntrinsicBounds(null, emptyDrawable, null, null);
mEmptyView.setText(emptyStringResId);
}
@@ -131,14 +131,11 @@ public class SelectableListLayout extends RelativeLayout {
* Initializes the view shown when the selectable list is empty.
*
- * @param emptyIconResId The icon to show when the selectable list is empty.
+ * @param emptyDrawable The Drawable to show when the selectable list is empty.
* @param emptyStringResId The string to show when the selectable list is empty.
*/

Powered by Google App Engine
This is Rietveld 408576698